pub struct File { /* private fields */ }Expand description
A File in a git repository.
The representation is lightweight and contains the Oid that
points to the git blob which is this file.
The name of a file can be retrieved via File::name.
The FileContent of a file can be retrieved via
File::content.
Implementations
Sourceimpl File
impl File
Sourcepub fn path(&self) -> PathBuf
pub fn path(&self) -> PathBuf
Return the exact path for this File, including the name of
the directory itself.
The path is relative to the git repository root.
Sourcepub fn location(&self) -> &Path
pub fn location(&self) -> &Path
Return the Path where this File is located, relative to the
git repository root.
Sourcepub fn content<'a>(&self, repo: &'a Repository) -> Result<FileContent<'a>, File>
pub fn content<'a>(&self, repo: &'a Repository) -> Result<FileContent<'a>, File>
Get the FileContent for this File.
Errors
This function will fail if it could not find the git blob
for the Oid of this File.