pub struct Repository { /* private fields */ }Expand description
Represents the state associated with a Git repository.
Many other types in this crate are derived from methods in this struct.
Implementations
Sourceimpl Repository
impl Repository
Sourcepub fn discover(repo_uri: impl AsRef<Path>) -> Result<Self, Error>
pub fn discover(repo_uri: impl AsRef<Path>) -> Result<Self, Error>
Attempt to open a git repository at or above repo_uri in the file
system.
Sourcepub fn which_namespace(&self) -> Result<Option<Namespace>, Error>
pub fn which_namespace(&self) -> Result<Option<Namespace>, Error>
What is the current namespace we’re browsing in.
Sourcepub fn switch_namespace(&self, namespace: &RefString) -> Result<(), Error>
pub fn switch_namespace(&self, namespace: &RefString) -> Result<(), Error>
Switch to a namespace
pub fn with_namespace<T, F>( &self, namespace: &RefString, f: F, ) -> Result<T, Error>
Sourcepub fn branches<'a, G>(&'a self, pattern: G) -> Result<Branches<'a>, Error>
pub fn branches<'a, G>(&'a self, pattern: G) -> Result<Branches<'a>, Error>
Returns an iterator of branches that match pattern.
Sourcepub fn branch_names<'a, G>(
&'a self,
filter: G,
) -> Result<BranchNames<'a>, Error>
pub fn branch_names<'a, G>( &'a self, filter: G, ) -> Result<BranchNames<'a>, Error>
Lists branch names with filter.
Returns an iterator of tags that match pattern.
Sourcepub fn tag_names<'a>(
&'a self,
filter: &Glob<Tag>,
) -> Result<TagNames<'a>, Error>
pub fn tag_names<'a>( &'a self, filter: &Glob<Tag>, ) -> Result<TagNames<'a>, Error>
Lists tag names in the local RefScope.
pub fn categories<'a>( &'a self, pattern: &Glob<Qualified<'_>>, ) -> Result<Categories<'a>, Error>
Sourcepub fn namespaces(&self, pattern: &Glob<Namespace>) -> Result<Namespaces, Error>
pub fn namespaces(&self, pattern: &Glob<Namespace>) -> Result<Namespaces, Error>
Returns an iterator of namespaces that match pattern.
Sourcepub fn diff(
&self,
from: impl Revision,
to: impl Revision,
) -> Result<Diff, Error>
pub fn diff( &self, from: impl Revision, to: impl Revision, ) -> Result<Diff, Error>
Get the Diff between two commits.
Sourcepub fn diff_commit(&self, commit: impl ToCommit) -> Result<Diff, Error>
pub fn diff_commit(&self, commit: impl ToCommit) -> Result<Diff, Error>
Get the Diff of a commit.
If the commit has a parent, then it the diff will be a
comparison between itself and that parent. Otherwise, the left
hand side of the diff will pass nothing.
Sourcepub fn diff_file<P: AsRef<Path>, R: Revision>(
&self,
path: &P,
from: R,
to: R,
) -> Result<FileDiff, Error>
pub fn diff_file<P: AsRef<Path>, R: Revision>( &self, path: &P, from: R, to: R, ) -> Result<FileDiff, Error>
Sourcepub fn root_dir<C: ToCommit>(&self, commit: C) -> Result<Directory, Error>
pub fn root_dir<C: ToCommit>(&self, commit: C) -> Result<Directory, Error>
Returns a top level Directory without nested sub-directories.
To visit inside any nested sub-directories, call directory.get(&repo)
on the sub-directory.
Sourcepub fn directory<C: ToCommit, P: AsRef<Path>>(
&self,
commit: C,
path: &P,
) -> Result<Directory, Error>
pub fn directory<C: ToCommit, P: AsRef<Path>>( &self, commit: C, path: &P, ) -> Result<Directory, Error>
Returns a Directory for path in commit.
Sourcepub fn file<C: ToCommit, P: AsRef<Path>>(
&self,
commit: C,
path: &P,
) -> Result<File, Error>
pub fn file<C: ToCommit, P: AsRef<Path>>( &self, commit: C, path: &P, ) -> Result<File, Error>
Returns a File for path in commit.
Sourcepub fn tree<C: ToCommit, P: AsRef<Path>>(
&self,
commit: C,
path: &P,
) -> Result<Tree, Error>
pub fn tree<C: ToCommit, P: AsRef<Path>>( &self, commit: C, path: &P, ) -> Result<Tree, Error>
Returns a Tree for path in commit.
Sourcepub fn blob<'a, C: ToCommit, P: AsRef<Path>>(
&'a self,
commit: C,
path: &P,
) -> Result<Blob<BlobRef<'a>>, Error>
pub fn blob<'a, C: ToCommit, P: AsRef<Path>>( &'a self, commit: C, path: &P, ) -> Result<Blob<BlobRef<'a>>, Error>
Returns a Blob for path in commit.
pub fn blob_ref(&self, oid: Oid) -> Result<BlobRef<'_>, Error>
Sourcepub fn last_commit<P, C>(
&self,
path: &P,
rev: C,
) -> Result<Option<Commit>, Error>
pub fn last_commit<P, C>( &self, path: &P, rev: C, ) -> Result<Option<Commit>, Error>
Returns the last commit, if exists, for a path in the history of
rev.
Sourcepub fn commit<R: Revision>(&self, rev: R) -> Result<Commit, Error>
pub fn commit<R: Revision>(&self, rev: R) -> Result<Commit, Error>
Returns a commit for rev, if it exists.
Sourcepub fn stats(&self) -> Result<Stats, Error>
pub fn stats(&self) -> Result<Stats, Error>
Gets the Stats of this repository starting from the
HEAD (see Repository::head) of the repository.
Sourcepub fn stats_from<R>(&self, rev: &R) -> Result<Stats, Error>where
R: Revision,
pub fn stats_from<R>(&self, rev: &R) -> Result<Stats, Error>where
R: Revision,
Gets the Stats of this repository starting from the given
rev.
Sourcepub fn get_commit_file<'a, P, R>(
&'a self,
rev: &R,
path: &P,
) -> Result<FileContent<'a>, Error>
pub fn get_commit_file<'a, P, R>( &'a self, rev: &R, path: &P, ) -> Result<FileContent<'a>, Error>
Retrieves the file with path in this commit.
Sourcepub fn extract_signature(
&self,
commit: impl ToCommit,
field: Option<&str>,
) -> Result<Option<Signature>, Error>
pub fn extract_signature( &self, commit: impl ToCommit, field: Option<&str>, ) -> Result<Option<Signature>, Error>
Extract the signature from a commit
Arguments
field - the name of the header field containing the signature block;
pass None to extract the default ‘gpgsig’
Sourcepub fn history<'a, C: ToCommit>(&'a self, head: C) -> Result<History<'a>, Error>
pub fn history<'a, C: ToCommit>(&'a self, head: C) -> Result<History<'a>, Error>
Returns the history with the head commit.
Sourcepub fn revision_branches(
&self,
rev: impl Revision,
glob: Glob<Branch>,
) -> Result<Vec<Branch>, Error>
pub fn revision_branches( &self, rev: impl Revision, glob: Glob<Branch>, ) -> Result<Vec<Branch>, Error>
Lists branches that are reachable from rev.