Struct radicle_surf::vcs::git::RepositoryRef
source · [−]pub struct RepositoryRef<'a> { /* private fields */ }Expand description
A reference-only Repository. This means that we cannot mutate the
underlying Repository. Not being able to mutate the Repository means
that the functions defined for RepositoryRef should be thread-safe.
Construction
Use the From<&'a git2::Repository> implementation to construct a
RepositoryRef.
Implementations
sourceimpl<'a> RepositoryRef<'a>
impl<'a> RepositoryRef<'a>
sourcepub fn which_namespace(&self) -> Result<Option<Namespace>, Error>
pub fn which_namespace(&self) -> Result<Option<Namespace>, Error>
What is the current namespace we’re browsing in.
sourcepub fn list_branches(&self, scope: RefScope) -> Result<Vec<Branch>, Error>
pub fn list_branches(&self, scope: RefScope) -> Result<Vec<Branch>, Error>
List the branches within a repository, filtering out ones that do not parse correctly.
Errors
List the tags within a repository, filtering out ones that do not parse correctly.
Errors
sourcepub fn list_namespaces(&self) -> Result<Vec<Namespace>, Error>
pub fn list_namespaces(&self) -> Result<Vec<Namespace>, Error>
List the namespaces within a repository, filtering out ones that do not parse correctly.
Errors
sourcepub fn diff(&self, from: Oid, to: Oid) -> Result<Diff, Error>
pub fn diff(&self, from: Oid, to: Oid) -> Result<Diff, Error>
Get the Diff between two commits.